@@ -10,7 +10,7 @@
 # ABSTRACT: Check the configuration of an application
 
 package App::Cme::Command::check ;
-$App::Cme::Command::check::VERSION = '1.013';
+$App::Cme::Command::check::VERSION = '1.015';
 use strict;
 use warnings;
 use 5.10.1;
@@ -52,7 +52,8 @@ sub execute {
     say "loading data" unless $opt->{quiet};
     Config::Model::ObjTreeScanner->new( leaf_cb => sub { } )->scan_node( undef, $root );
     say "checking data" unless $opt->{quiet};
-    $root->dump_tree( mode => 'full' );
+    $root->dump_tree( mode => 'full' ); # light check (value per value)
+    $root->deep_check; # consistency check
     say "check done" unless $opt->{quiet};
 
     my $ouch = $inst->has_warning;
@@ -78,7 +79,7 @@ App::Cme::Command::check - Check the configuration of an application
 
 =head1 VERSION
 
-version 1.013
+version 1.015
 
 =head1 SYNOPSIS
 
